pub struct Client { /* private fields */ }
A fluent API for configuring and executing pavexc’s CLI commands.

Implementations

source

impl Client

source

pub fn new() -> Self

Create a new Client with the default configuration.

source

pub fn generate( self, blueprint: BlueprintArgument, output_directory: PathBuf ) -> GenerateBuilder

Start building the configuration for the code-generator.

You must specify:

  • The Blueprint for the application that you want to generate;
  • The directory where the generated code should be written.
source

pub fn new_command(self, path: PathBuf) -> NewBuilder

Start building the configuration for the new command.

You must specify the path where the new project should be created.

source

impl Client

Setters for optional configuration knobs on Client.

source

pub fn pavexc_cli_path(self, path: PathBuf) -> Self

Set the path to the pavexc executable.

If this is not set, we will assume that pavexc is in the PATH.

source

pub fn color(self, color: Color) -> Self

Set whether to use colors in the output of Pavex’s code generator.

If this is not set, Pavex will automatically determine whether to use colors or not.

source

pub fn debug(self) -> Self

Enable debug mode.

This will print additional debug information when running pavexc commands.

source

pub fn no_debug(self) -> Self

Disable debug mode.

pavexc will not print additional debug information when running commands. This is the default behaviour.