Struct pavexc_cli_client::client::Client
source · pub struct Client { /* private fields */ }Expand description
A fluent API for configuring and executing pavexc’s CLI commands.
Implementations
sourceimpl Client
impl Client
sourcepub fn generate(
self,
blueprint: BlueprintArgument,
output_directory: PathBuf
) -> GenerateBuilder
pub fn generate( self, blueprint: BlueprintArgument, output_directory: PathBuf ) -> GenerateBuilder
Start building the configuration for the code-generator.
You must specify:
- The
Blueprintfor the application that you want to generate; - The directory where the generated code should be written.
sourcepub fn new_command(self, path: PathBuf) -> NewBuilder
pub fn new_command(self, path: PathBuf) -> NewBuilder
Start building the configuration for the new command.
You must specify the path where the new project should be created.
sourceimpl Client
impl Client
Setters for optional configuration knobs on Client.
sourcepub fn pavexc_cli_path(self, path: PathBuf) -> Self
pub fn pavexc_cli_path(self, path: PathBuf) -> Self
Set the path to the pavexc executable.
If this is not set, we will assume that pavexc is in the PATH.
sourcepub fn color(self, color: Color) -> Self
pub fn color(self, color: Color) -> Self
Set whether to use colors in the output of Pavex’s code generator.
If this is not set, Pavex will automatically determine whether to use colors or not.